.. _server:

Administering a server
======================

.. _server-installation:

Installation
------------

.. toctree::
   :maxdepth: 2

   requirements
   installation
   project_setup
   mysql_installation
   postgresql_installation
   web


.. _server-upgrading:

Upgrading
---------

.. toctree::
   :maxdepth: 2

   upgrading
   database_migration


.. _server-management:

Performance tuning and managing the server
------------------------------------------

.. toctree::
   :maxdepth: 2

   settings
   logging
   optimization
   cache
   auth
   commands
   rq
   backup
